*========================PROGRAM: IQI_ALL_MEASURES.SAS=========================;
*
*  DESCRIPTION:
*         Assigns the IQI outcome measure of interest to inpatient records. 
*         variables created by this program are TPIQXX and stratifiers.
*
*  VERSION: SAS QI v2018 (ICD-10 CM/PCS)
*  RELEASE DATE: JUNE 2018
*
*  USER NOTE1: Make sure you have created the format library
*              using IQI_FORMATS.SAS BEFORE running this program.
*
*  USER NOTE2: The AHRQ QI software does not support the calculation of weighted 
*              estimates and standard errors using complex sampling designs. 
*
*  USER NOTE3: The IQI indicators 23, 24, 25, 26, 27, 28, and 29 were removed 
*              from version 7.0.
*
*===============================================================================;

%LET PATHNAME=C:\pathname\IQI; *<===USER MUST modify;
filename CONTROL "&PATHNAME.\Programs\IQI_ALL_CONTROL.SAS";

%INCLUDE CONTROL;

 title2 'IQI_ALL_MEASURES PROGRAM';
 title3 'AHRQ INPATIENT QUALITY INDICATORS: ASSIGN IQIS TO INPATIENT DATA';

 * ----------------------------------------------------------------- ;
 * --- CREATE A PERMANENT DATASET CONTAINING ALL RECORDS THAT    --- ; 
 * --- WILL NOT BE INCLUDED IN ANALYSIS BECAUSE KEY VARIABLE     --- ;
 * --- VALUES ARE MISSING. REVIEW AFTER RUNNING IQI_ALL_MEASURES.--- ;
 * ----------------------------------------------------------------- ;

 data   OUTMSR.&DELFILE.
   (keep=KEY HOSPID SEX AGE DX1 MDC YEAR DQTR);
 set  INMSR.&DISCHARGE.;
 if (AGE lt 0) or (AGE lt 18 and MDC notin (14)) or (SEX le 0) or 
   (DX1 in (' ')) or (DQTR le .Z) or (YEAR le .Z);
 run;
 * --- Include standard diagnosis and procedure macros. ---* ;
 %include MacLib(IQI_Dx_Px_Macros.sas) ;

 * -------------------------------------------------------------- ;
 * --- INPATIENT QUALITY INDICATOR (IQI) NAMING CONVENTION:   --- ;
 * --- THE FIRST LETTER IDENTIFIES THE INPATIENT QUALITY      --- ;
 * --- INDICATOR AS ONE OF THE FOLLOWING:
                (T) NUMERATOR ("TOP")
 * --- THE SECOND LETTER IDENTIFIES THE IQI AS A PROVIDER (P) --- ;
 * --- LEVEL INDICATOR.  THE NEXT TWO CHARACTERS ARE ALWAYS   --- ;
 * --- 'IQ'. THE LAST TWO DIGITS ARE THE INDICATOR NUMBER     --- ;
 * --- (WITHIN THAT SUBTYPE).                                 --- ;
 * -------------------------------------------------------------- ;

 data   OUTMSR.&OUTFILE_MEAS.
    (keep=KEY HOSPID DRG MDC SEX AGE YEAR DQTR
          AGECAT SEXCAT RACECAT PAYCAT 
          TPIQ01  TPIQ02   TPIQ02A  TPIQ02B TPIQ04  TPIQ04A--TPIQ04D TPIQ05-TPIQ09 
          TPIQ09A  TPIQ09B  TPIQ11  TPIQ11A--TPIQ11D TPIQ12-TPIQ17 
          TPIQ17A--TPIQ17C TPIQ18-TPIQ20 TPIQ30-TPIQ34
          TPIQ21-TPIQ22
    );

 set   INMSR.&DISCHARGE.
    (keep=KEY HOSPID DRG MDC SEX AGE RACE YEAR DQTR
          PAY1 DISP ASOURCE POINTOFORIGINUB04 
          DX1-DX&NDX. PR1-PR&NPR. %ADDPRDAY);

 * ------------------------------------------------------------------------ ;
 * -- DELETE RECORDS WITH MISSING VALUES FOR AGE, SEX, DX1, DQTR, & YEAR -- ;
 * -- DELETE NON ADULT RECORDS                                           -- ;
 * ------------------------------------------------------------------------ ;
 if SEX le 0 then delete;
 if AGE lt 0 then delete;
 if AGE lt 18 and MDC notin (14) then delete;
 if DX1 in (' ') then delete;
 if DQTR le .Z then delete;
 if YEAR le .Z then delete;

 * --------------------------------------------------------------------- ;
 * --- DEFINE MDC ------------------------------------------------------ ;
 * --------------------------------------------------------------------- ;
 * --- The software assumes MDC is available on the input file.       -- ;
 * --- If MDC is not available, assign using the CMS MS-DRG Grouper.  -- ;
 * --------------------------------------------------------------------- ;

 attrib MDCNEW length=3
   label='RESPECIFIED MDC';

 if MDC notin (01,02,03,04,05,06,07,08,09,10,
               11,12,13,14,15,16,17,18,19,20,
               21,22,23,24,25)
 then do;
    MDCNEW = put(DRG,MDCF2T.);
    if MDCNEW in (01,02,03,04,05,06,07,08,09,10,
                  11,12,13,14,15,16,17,18,19,20,
                  21,22,23,24,25)
    then MDC=MDCNEW;
    else do;
       if DRG in (999) then MDC = 0;
       else put "INVALID MDC KEY: " KEY " MDC " MDC " DRG " DRG ;
    end;
 end;
 

* -------------------------------------------------------------- ;
 * --- DEFINE ICD-10-CM VERSION -------------------------------- ;
 * ------------------------------------------------------------- ;
 attrib ICDVER length=3
   label='ICD-10-CM VERSION';

 ICDVER = 0;
 if (YEAR in (2015) and DQTR in (4))          then ICDVER = 33;
 else if (YEAR in (2016) and DQTR in (1,2,3)) then ICDVER = 33;
 else if (YEAR in (2016) and DQTR in (4))     then ICDVER = 34;
 else if (YEAR in (2017) and DQTR in (1,2,3)) then ICDVER = 34;
 else if (YEAR in (2017) and DQTR in (4))     then ICDVER = 35;
 else if (YEAR in (2018) and DQTR in (1,2,3)) then ICDVER = 35;
 else ICDVER = 35; *Defaults to last version for discharges outside coding updates
   
 * ------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: PAYER CATEGORY ----------------------- ;
 * ------------------------------------------------------------- ;
 attrib PAYCAT length=3
   label='PATIENT PRIMARY PAYER';

 select (PAY1);
   when (1)  PAYCAT = 1;
   when (2)  PAYCAT = 2;
   when (3)  PAYCAT = 3;
   when (4)  PAYCAT = 4;
   when (5)  PAYCAT = 5;
   otherwise PAYCAT = 6;
 end; 


 * ------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: RACE CATEGORY ------------------------ ;
 * ------------------------------------------------------------- ;
 attrib RACECAT length=3
   label='PATIENT RACE/ETHNICITY';

 select (RACE);
   when (1)  RACECAT = 1;
   when (2)  RACECAT = 2;
   when (3)  RACECAT = 3;
   when (4)  RACECAT = 4;
   when (5)  RACECAT = 5;
   otherwise RACECAT = 6;
 end; 
 

 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: AGE CATEGORY  ------------------------- ;
 * -------------------------------------------------------------- ;
 attrib AGECAT length=3
   label='PATIENT AGE';

 select;
   when (      AGE < 18)  AGECAT = 0;
   when (18 <= AGE < 40)  AGECAT = 1;
   when (40 <= AGE < 65)  AGECAT = 2;
   when (65 <= AGE < 75)  AGECAT = 3;
   when (75 <= AGE     )  AGECAT = 4;
   otherwise AGECAT = 0;
 end;


 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: SEX CATEGORY  ------------------------- ;
 * -------------------------------------------------------------- ;
 attrib SEXCAT length=3
   label='PATIENT SEX';

 select (SEX);
   when (1)  SEXCAT = 1;
   when (2)  SEXCAT = 2;
   otherwise SEXCAT = 0;
 end;


 * -------------------------------------------------------------- ;
 * --- DEFINE PROVIDER LEVEL VOLUME INDICATORS ------------------ ;
 * -------------------------------------------------------------- ;

 attrib
 TPIQ01 length=8
   label='IQI 01 Esophageal Resection Volume (Numerator)'
 TPIQ02 length=8
   label='IQI 02 Pancreatic Resection Volume (Numerator)'
 TPIQ02A length=8
   label='IQI 02A Pancreatic Resection Volume Stratum A: Presence of Pancreatic Cancer Diagnosis (Numerator)'
 TPIQ02B length=8
   label='IQI 02B Pancreatic Resection Volume Stratum B: Absence of Pancreatic Cancer Diagnosis (Numerator)'
 TPIQ04 length=8
   label='IQI 04 Abdominal Aortic Aneurysm (AAA) Repair Volume (Numerator)'
 TPIQ04A length=8
   label='IQI 04A Abdominal Aortic Aneurysm Repair Volume Stratum A: Open Repair of Ruptured AAA (Numerator)'
 TPIQ04B length=8
   label='IQI 04B Abdominal Aortic Aneurysm Repair Volume Stratum B: Open Repair of Unruptured AAA (Numerator)'
 TPIQ04C length=8
   label='IQI 04C Abdominal Aortic Aneurysm Repair Volume Stratum C: Endovascular Repair of Ruptured AAA (Numerator)'
 TPIQ04D length=8
   label='IQI 04D Abdominal Aortic Aneurysm Repair Volume Stratum D: Endovascular Repair of Unruptured AAA (Numerator)'
 TPIQ05 length=8
   label='IQI 05 Coronary Artery Bypass Graft (CABG) Volume (Numerator)'
 TPIQ06 length=8
   label='IQI 06 Percutaneous Coronary Intervention (PCI) Volume (Numerator)'
 TPIQ07 length=8
   label='IQI 07 Carotid Endarterectomy Volume (Numerator)'
;

 * -------------------------------------------------------------- ;
 * --- DEFINE PROVIDER LEVEL MORTALITY INDICATORS --------------- ;
 * -------------------------------------------------------------- ;
 attrib
 TPIQ08 length=8
   label='IQI 08 Esophageal Resection Mortality Rate (Numerator)'
 TPIQ09 length=8                           
   label='IQI 09 Pancreatic Resection Mortality Rate (Numerator)'
 TPIQ09A length=8                           
   label='IQI 09A Pancreatic Resection Mortality Rate Stratum A: Presence of Pancreatic Cancer (Numerator)'
 TPIQ09B length=8                           
   label='IQI 09B Pancreatic Resection Mortality Rate Stratum B: Absence of Pancreatic Cancer (Numerator)'
 TPIQ11 length=8
   label='IQI 11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate (Numerator)'
 TPIQ11A length=8
   label='IQI 11A Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum Open/Ruptured: Open Repair of Ruptured AAA (Numerator)'
 TPIQ11B length=8
   label='IQI 11B Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum Open/Intact: Open Repair of Unruptured AAA (Numerator)'
 TPIQ11C length=8
   label='IQI 11C Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum Endo/Ruptured: Endovascular Repair of Ruptured AAA (Numerator)'
 TPIQ11D length=8
   label='IQI 11D Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum Endo/Intact: Endovascular Repair of Unruptured AAA (Numerator)'
 TPIQ12 length=8
   label='IQI 12 Coronary Artery Bypass Graft (CABG) Mortality Rate (Numerator)'
 TPIQ13 length=8
   label='IQI 13 Craniotomy Mortality Rate (Numerator)'
 TPIQ14 length=8
   label='IQI 14 Hip Replacement Mortality Rate (Numerator)'
 TPIQ15 length=8
   label='IQI 15 Acute Myocardial Infarction (AMI) Mortality Rate (Numerator)'
 TPIQ16 length=8
   label='IQI 16 Heart Failure Mortality Rate (Numerator)'
 TPIQ17 length=8
   label='IQI 17 Acute Stroke Mortality Rate (Numerator)'
 TPIQ17A length=8
   label='IQI 17 Acute Stroke Mortality Rate Stratum A: Subarachnoid Hemorrhage (Numerator)'
 TPIQ17B length=8
   label='IQI 17 Acute Stroke Mortality Rate Stratum B: Intracerebral Hemorrhage (Numerator)'
 TPIQ17C length=8
   label='IQI 17 Acute Stroke Mortality Rate Stratum C: Ischemic Stroke (Numerator)'
 TPIQ18 length=8
   label='IQI 18 Gastrointestinal Hemorrhage Mortality Rate (Numerator)'
 TPIQ19 length=8
   label='IQI 19 Hip Fracture Mortality Rate (Numerator)'
 TPIQ20 length=8
   label='IQI 20 Pneumonia Mortality Rate (Numerator)'
;
  
 * -------------------------------------------------------------- ;
 * --- DEFINE ADDITIONAL PROVIDER LEVEL MORTALITY INDICATORS ---- ;
 * -------------------------------------------------------------- ;
 attrib
 TPIQ30 length=8
   label='IQI 30 Percutaneous Coronary Intervention (PCI) Mortality Rate (Numerator)'
 TPIQ31 length=8
   label='IQI 31 Carotid Endarterectomy Mortality Rate (Numerator)'
 TPIQ32 length=8
   label='IQI 32 Acute Myocardial Infarction (AMI) Mortality Rate, Without Transfer Cases (Numerator)'
;

 * -------------------------------------------------------------- ;
 * --- DEFINE PROVIDER LEVEL UTILIZATION INDICATORS ------------- ;
 * -------------------------------------------------------------- ;
 attrib
 TPIQ21 length=8
   label='IQI 21 Cesarean Delivery Rate, Uncomplicated (Numerator)'
 TPIQ22 length=8
   label='IQI 22 Vaginal Birth After Cesarean (VBAC) Delivery Rate, Uncomplicated (Numerator)'
;

 * -------------------------------------------------------------- ;
 * --- DEFINE ADDITIONAL PROVIDER LEVEL UTILIZATION INDICATORS -- ;
 * -------------------------------------------------------------- ;
 attrib
 TPIQ33 length=8
   label='IQI 33 Primary Cesarean Delivery Rate, Uncomplicated (Numerator)'
 TPIQ34 length=8
   label='IQI 34 Vaginal Birth After Cesarean (VBAC) Rate, All (Numerator)'
;

 
 * ------------------------------------------------------- ;
 * --- CONSTRUCT PROVIDER LEVEL INDICATORS --------------- ;
 * ------------------------------------------------------- ;

 * --- CONSTRUCT PROVIDER LEVEL VOLUME INDICATORS --- ;

 * -------------------------------------------------- ;
 * --- IQI 01 : VOLUME ESOPHAGEAL RESECTION       --- ;
 * -------------------------------------------------- ;

   if (%MPR($PRESOPP.) or 
      (%MPR($PRESO2P.) and %MDX($PRESOPD.))) 
   then

      TPIQ01 = 1;

  
 * -------------------------------------------------- ;
 * --- IQI 02 : VOLUME PANCREATIC RESECTION       --- ;
 * -------------------------------------------------- ;

   if (%MPR($PRPANCP.) or %MPR($PRPAN3P.)) then do;

         TPIQ02 = 1;

         if (%MDX($PRPANCD.)) then TPIQ02A = 1 ;

         else TPIQ02B = 1 ;

   end;

      if %MDX($PRPAN2D.) then do;

      TPIQ02 = .;
      TPIQ02A = .; 
      TPIQ02B = .;

   end;


 * -------------------------------------------------------------- ;
 * --- IQI 04 : VOLUME ABDOMINAL AORTIC ANEURYSM (AAA) REPAIR --- ;
 * -------------------------------------------------------------- ;

   if (%MDX($PRAAARD.) or %MDX($PRAAA2D.)) and 
      (%MPR($PRAAARP.) or %MPR($PRAAA2P.)) then

      TPIQ04 = 1;


   * --- VOLUME AAA REPAIR (STRATIFICATION)                             --- ;
   * --- stratification priority according to prior probability of death ---;


        /** IQI 04A : OPEN REPAIR - RUPTURED ***/ 


      if %MPR($PRAAARP.) and %MDX($PRAAARD.) then do;
         TPIQ04A = 1;
      end;

      /** IQI 04C : ENDOVASCULAR REPAIR  - RUPTURED ***/


      else if %MPR($PRAAA2P.) and %MDX($PRAAARD.) then do;
         TPIQ04C = 1;
      end;

      /** IQI 04B : OPEN REPAIR - UNRUPTURED ***/


      else if %MPR($PRAAARP.) and %MDX($PRAAA2D.) then do;
         TPIQ04B = 1;
      end;

       /** IQI 04D : ENDOVASCULAR REPAIR - UNRUPTURED ***/


      else if %MPR($PRAAA2P.) and %MDX($PRAAA2D.) then do;
         TPIQ04D = 1;
      end;


 * ----------------------------------------------------------- ;
 * --- IQI 05 : CORONARY ARTERY BYPASS GRAFT (CABG) VOLUME --- ;
 * ----------------------------------------------------------- ;

   if %MPR($PRCABGP.) then

      TPIQ05 = 1;

 * ---------------------------------------------------------------- ;
 * --- IQI 06 : PERCUTANEOUS CORONARY INTERVENTION (PCI) VOLUME --- ;
 * ---------------------------------------------------------------- ;

   if %MPR($PRPTCAP.) then

      TPIQ06 = 1;

 * -------------------------------------------------- ;
 * --- IQI 07 : CAROTID ENDARTERECTOMY VOLUME     --- ;
 * -------------------------------------------------- ;

   if %MPR($PRCEATP.) then

      TPIQ07 = 1;


 * --- CONSTRUCT PROVIDER LEVEL MORTALITY INDICATORS --- ;


 * ----------------------------------------------------- ;
 * --- IQI 08 : ESOPHAGEAL RESECTION MORTALITY RATE	 --- ;
 * ----------------------------------------------------- ;

   if MDC notin (14) and
      ((%MPR($PRESOPP.) and (%MDX($PRESOPD.) or %MDX($PRESO2D.))) or 
       (%MPR($PRESO2P.) and %MDX($PRESOPD.))) 
   then do;

      TPIQ08 = 0; 
      if DISP in (20) then TPIQ08 = 1;

   end;

  
 * ---------------------------------------------------- ; 
 * --- IQI 09 : PANCREATIC RESECTION MORTALITY RATE --- ;
 * ---------------------------------------------------- ;

   if MDC notin (14) and (%MPR($PRPANCP.) or %MPR($PRPAN3P.)) then do;

      TPIQ09 = 0; 
      if DISP in (20) then TPIQ09 = 1;

     if %MDX($PRPANCD.) then do;
         TPIQ09A = 0; 
            if DISP in (20) then TPIQ09A = 1;
     end;
     else do;
          TPIQ09B = 0;  
         if DISP in (20) then TPIQ09B = 1;
     end;

    * ---------------------------------------------- ;
    * --- EXCLUDE ACUTE PANCREATITIS             --- ;
    * ---------------------------------------------- ;

      if %MDX($PRPAN2D.) then do;
         TPIQ09 = .;
         TPIQ09A = .;
         TPIQ09B = .;
     end;

    end;


 * ---------------------------------------------------------------------- ;
 * --- IQI 11 : ABDOMINAL AORTIC ANEURYSM (AAA) REPAIR MORTALITY RATE --- ;
 * ---------------------------------------------------------------------- ;

   if MDC notin (14) and 
      (%MDX($PRAAARD.) or %MDX($PRAAA2D.)) and 
      (%MPR($PRAAARP.) or %MPR($PRAAA2P.))

      then do;

      TPIQ11 = 0;  

      if DISP in (20) then TPIQ11 = 1;

   end;

   * --- IN-HOSP MORT AAA REPAIR (STRATIFICATION)                        --- ;
   * --- stratification priority according to prior probability of death --- ;
   
   if MDC notin (14) then do;

      /** IQI 11A : OPEN REPAIR- RUPTURED ***/
     if %MPR($PRAAARP.) and %MDX($PRAAARD.) then do;
        TPIQ11A = 0; 
       if DISP in (20) then TPIQ11A = 1;
     end;

     /** IQI 11C : ENDOVASCULAR REPAIR - RUPTURED ***/
     else if %MPR($PRAAA2P.) and %MDX($PRAAARD.) then do;
        TPIQ11C = 0;
       if DISP in (20) then TPIQ11C = 1;
     end;

     /** IQI 11B : OPEN REPAIR- UNRUPTURED ***/
     else if %MPR($PRAAARP.) and %MDX($PRAAA2D.) then do;
         TPIQ11B = 0;
          if DISP in (20) then TPIQ11B = 1;
     end;

     /** IQI 11D : ENDOVASCULAR REPAIR  - UNRUPTURED ***/
     else if %MPR($PRAAA2P.) and %MDX($PRAAA2D.) then do;
        TPIQ11D = 0;
       if DISP in (20) then TPIQ11D = 1;
     end;

   end;


 * ------------------------------------------------------------------- ;
 * --- IQI 12 : CORONARY ARTERY BYPASS GRAFT (CABG) MORTALITY RATE --- ;
 * --------------------------------------*---------------------------- ;

   if MDC notin (14) and (AGE >= 40) and
      %MPR($PRCABGP.) 
   then do;

      TPIQ12 = 0; 
      if DISP in (20) then TPIQ12 = 1;

   end;

 * ------------------------------------------ ;
 * --- IQI 13 : CRANIOTOMY MORTALITY RATE --- ;
 * ------------------------------------------ ;

   if %MDR($CRANIO2G.) then do;

      TPIQ13 = 0; 
      if DISP in (20) then TPIQ13 = 1;

     *** Exclude Head Trauma;
      if %MDX1($HTRAUID.) then TPIQ13 = .; 

   end;

 * ----------------------------------------------- ;
 * --- IQI 14 : HIP REPLACEMENT MORTALITY RATE --- ;
 * ----------------------------------------------- ;

   if MDC notin (14) and 
      %MPR($MTHIPRP.) and %MDX($MTHIPRD.) 
   then do;

      TPIQ14 = 0;
      if DISP in (20) then TPIQ14 = 1;

      * Exclude hip fracture;
      if %MDX($MTHIPFD.) then TPIQ14 = .;  

   end;

 * ----------------------------------------------------------------- ;
 * --- IQI 15 : ACUTE MYOCARDIAL INFARCTION (AMI) MORTALITY RATE --- ;
 * ----------------------------------------------------------------- ;

   if MDC notin (14) and 
      %MDX1($MRTAMID.) then do;

      TPIQ15 = 0;
      TPIQ32 = 0;

       if DISP in (20) then do;
         TPIQ15 = 1;
         TPIQ32 = 1;
      end;

     * Exclusion for cases in hospice care at admission ;
      if POINTOFORIGINUB04 in ('F') then do;
        TPIQ15 = .;
         TPIQ32 = .;
      end;

   end;

   
 * --------------------------------------------- ;
 * --- IQI 16 : HEART FAILURE MORTALITY RATE --- ;
 * --------------------------------------------- ;

   if MDC notin (14) and
      %MDX1($MRTCHFD.) 
   then do;

      TPIQ16 = 0;
      if DISP in (20) then TPIQ16 = 1;
     
     * Exclude any procedure code for heart transplant ;
      if %MPR($HEARTTRP.) then TPIQ16 = .;
     
     * Exclusion for cases in hospice care at admission ;
     if POINTOFORIGINUB04 in ('F') then TPIQ16 = .;
     
   end;


 * -------------------------------------------- ;
 * --- IQI 17 : ACUTE STROKE MORTALITY RATE --- ;
 * -------------------------------------------- ;

   if MDC notin (14) and
      (%MDX1($MRTCV2A.) or %MDX1($MRTCV3D.) or %MDX1($MRTCV4D.))
   then do;

      TPIQ17 = 0; 

      if DISP in (20) then TPIQ17 = 1;

   end;

   * --- ACUTE STROKE MORTALITY (STRATIFICATION)                         --- ;
   * --- Stratification priority according to prior probability of death --- ;

   /* IQI 17 B : STRATUM 2: INTRACEREBRAL HEMORRHAGIC STROKE */

   if MDC notin (14) and %MDX1($MRTCV3D.) then do;

      TPIQ17B = 0;

      if DISP in (20) then TPIQ17B = 1;
 
   end;

   /* IQI 17A : STRATUM 1: SUBARACHNOID HEMORRHAGE  */

   else if MDC notin (14) and %MDX1($MRTCV2A.) then do;

      TPIQ17A = 0;

      if DISP in (20) then TPIQ17A = 1;
    end;

  /* IQI 17C : STRATUM 3: ISCHEMIC HEMORRHAGIC STROKE */

   else if MDC notin (14) and %MDX1($MRTCV4D.) then do;

      TPIQ17C = 0;

      if DISP in (20) then TPIQ17C = 1;
   end;

   * Exclusion for cases in hospice care at admission ;
   if POINTOFORIGINUB04 in ('F') then do;
     TPIQ17 = .;
     TPIQ17A = .;
     TPIQ17B = .;
     TPIQ17C = .;
   end;

 * ----------------------------------------------------------- ;
 * --- IQI 18 : GASTROINTESTINAL HEMORRHAGE MORTALITY RATE --- ;
 * ----------------------------------------------------------- ;

   if MDC notin (14) and
      (%MDX1($MRTGIHD.) or (%MDX2($FTR6GV.) and %MDX1($FTR6QD.)))
   then do;

      TPIQ18 = 0;
      if DISP in (20) then TPIQ18 = 1;

     * Exclusion for cases in hospice care at admission ;
     if POINTOFORIGINUB04 in ('F') then TPIQ18 = .;
     
     * Exclusion for liver transplant ;
      if %MPR($LIVERTRP.) then TPIQ18 = .;
     
   end;

 * -------------------------------------------- ;
 * --- IQI 19 : HIP FRACTURE MORTALITY RATE --- ;
 * -------------------------------------------- ;

   if MDC notin (14) and (AGE >= 65) and
      %MDX1($MTHIPFD.) 
   then do;

      TPIQ19 = 0; 
      if DISP in (20) then TPIQ19 = 1;

      * Exclude periprosthetic fracture;
      if %MDX($MTHIP2D.) then do;
         TPIQ19 = .; 
      end;

     * Exclusion for cases in hospice care at admission ;
     if POINTOFORIGINUB04 in ('F') then TPIQ19 = .;
     
   end;

 * ----------------------------------------- ;
 * --- IQI 20 : PNEUMONIA MORTALITY RATE --- ;
 * ----------------------------------------- ;

   if MDC notin (14) and
      %MDX1($MTPNEUD.) 
   then do;

      TPIQ20 = 0;
      if DISP in (20) then TPIQ20 = 1;

     * Exclusion for cases in hospice care at admission ;
     if POINTOFORIGINUB04 in ('F') then TPIQ20 = .;
     
   end;


 * --- CONSTRUCT ADDITIONAL PROVIDER LEVEL MORTALITY INDICATORS - ;

 * ------------------------------------------------------------------------ ;
 * --- IQI 30 : PERCUTANEOUS CORONARY INTERVENTION (PCI) MORTALITY RATE --- ;
 * ------------------------------------------------------------------------ ;

   if MDC notin (14) and (AGE >= 40) and 
      %MPR($PRPTCAP.) 
   then do;

      TPIQ30 = 0;
      if DISP in (20) then TPIQ30 = 1;

   end;

 * ------------------------------------------------------ ;
 * --- IQI 31 : CAROTID ENDARTERECTOMY MORTALITY RATE --- ;
 * ------------------------------------------------------ ;

   if MDC notin (14) and 
      %MPR($PRCEATP.) 
   then do;

      TPIQ31 = 0;
     if DISP in (20) then TPIQ31 = 1;

   end;


 * --- CONSTRUCT PROVIDER LEVEL UTILIZATION INDICATORS ---------- ;

 * --------------------------------------------------------- ;
 * --- IQI 21 : CESAREAN SECTION DELIVERY, UNCOMPLICATED --- ;
 * --------------------------------------------------------- ;

   if %MDX($DELOCMD.)
   then do;

      TPIQ21 = 0;

      if %MDR($PRCSE2G.) or 
         (%MPR($PRCSECP.) and not %MPR($PRCSE2P.)) then

         TPIQ21 = 1;

      if %MDX($PRCSECD.) then

         TPIQ21 = .;

   end;

 * --------------------------------------------------------------------------------- ;
 * --- IQI 22 : VAGINAL BIRTH AFTER CESAREAN (VBAC) DELIVERY RATE, UNCOMPLICATED --- ;
 * --------------------------------------------------------------------------------- ;

   if %MDX($DELOCMD.) and %MDX($PRVBACD.) 
   then do;

      TPIQ22 = 0;
      TPIQ34 = 0;

   if %MPR($VAGDELP.) then do;

         TPIQ22 = 1;
         TPIQ34 = 1;

      end;

      if %MDX($PRCSECD.) then

         TPIQ22 = .;

   end;

 * -------------------------------------------------------------- ;
 * --- IQI 33 : PRIMARY CESAREAN DELIVERY RATE, UNCOMPLICATED --- ;
 * -------------------------------------------------------------- ;

   if TPIQ21 NE . and TPIQ22 EQ . then TPIQ33 = TPIQ21;


 * -------------------------------------------------------------- ;
 * --- EXCLUDE CASES WITH MISSING VALUES FOR DISP OR ASOURCE  --- ;
 * -------------------------------------------------------------- ;

 if (DISP lt 0) then do;
   TPIQ08  = .;
   TPIQ09  = .; 
   TPIQ09A = .;
   TPIQ09B = .;
   TPIQ11  = .;
   TPIQ11A = .;
   TPIQ11B = .;
   TPIQ11C = .;
   TPIQ11D = .;
   TPIQ12  = .;
   TPIQ13  = .;
   TPIQ14  = .;
   TPIQ15  = .;
   TPIQ16  = .;
   TPIQ17  = .;
   TPIQ17A = .;
   TPIQ17B = .;
   TPIQ17C = .;
   TPIQ18  = .;
   TPIQ19  = .;
   TPIQ20  = .;
   TPIQ30  = .;
   TPIQ31  = .;
   TPIQ32  = .;
 end;

 if (ASOURCE lt 0) and (POINTOFORIGINUB04 in (' ')) then 
   TPIQ32 = .;

 * -------------------------------------------------------------- ;
 * --- EXCLUDE TRANSFERS ---------------------------------------- ;
 * -------------------------------------------------------------- ;

 * --- TRANSFER FROM ANOTHER ACUTE ---------------- ;
 if ASOURCE in (2) or POINTOFORIGINUB04 in ('4') then do; 
   TPIQ32 = .;
 end;

 * --- TRANSFER TO ANOTHER ACUTE ------------------ ;
 if DISP in (2) then do;
   TPIQ08   = .;
   TPIQ09   = .;
   TPIQ09A  = .; 
   TPIQ09B  = .;
   TPIQ11   = .;
   TPIQ11A  = .; 
   TPIQ11B  = .;
   TPIQ11C  = .;
   TPIQ11D  = .;
   TPIQ12   = .;
   TPIQ13   = .;
   TPIQ14   = .;
   TPIQ15   = .;
   TPIQ16   = .;
   TPIQ17   = .;
   TPIQ17A  = .;
   TPIQ17B  = .;
   TPIQ17C  = .;
   TPIQ18   = .;
   TPIQ19   = .;
   TPIQ20   = .;
   TPIQ30   = .;
   TPIQ31   = .;
   TPIQ32   = .;
 end;

run;

proc MEANS data=OUTMSR.&OUTFILE_MEAS. N NMISS MIN MAX MEAN SUM;
title "INPATIENT QUALITY INDICATOR NUMERATOR (=SUM),DENOMINATOR (=N), AND OBSERVED RATE (MEAN) ";
run;

proc CONTENTS data=OUTMSR.&OUTFILE_MEAS. POSITION;
title "INPATIENT QUALITY INDICATOR MEASURE OUTPUT ";
run;

proc PRINT data=OUTMSR.&OUTFILE_MEAS.(OBS=24);
title4 "FIRST 24 RECORDS IN OUTPUT DATA SET &OUTFILE_MEAS.";
run;
